# Muvinai Python package

## Instalar

~~~
pip install muvinai
~~~

## Actualizar

~~~
pip install --upgrade muvinai
~~~

## Crear una nueva version del paquete `muvinai`

Dentro de la página del proyecto en github (https://github.com/devmuvi/muvinai_pkg) crear un nuevo release. El tag del release debe ser el numero de version (ejemplo: 1.0.9).

Link al proyecto en **PyPI**: https://pypi.org/project/muvinai/

## Uso de la libreria

Las importaciones deben realizarse como en se muestra en el siguiente ejemplo:

~~~python
from muvinai.utilities.init_creds import init_mongo
~~~